function [h]=gquiv(var1, var2, clev, nthin, units);
%
%  function [h, hx] = gquiv(var1, var2, clev, nthin, units)
%
%  This function vectors the variables 'var1, var2' over
%  the global grid, with length specified by clev,
%  (use 0 for default) and axis limits specified by the
%  global variable FRAME. 
%

get_global
global x_coasts y_coasts

var1 = squeeze(var1);
var2 = squeeze(var2);

% set axis parameters:
if nargin < 3; 
  clev = 2;
  nthin = 1;
elseif nargin < 4;
  nthin = clev;
  clev = 2;
elseif nargin < 5;
  if isstr(nthin);
    units = nthin;
    nthin = 1;
  else
    units = [];
  end
end;

var1 = thin(var1, nthin);
var2 = thin(var2, nthin);
xax = thin(XAX, nthin);
yax = thin(YAX, nthin);

[xk, yk] = keep_var(FRAME, xax, yax);

% mess with var:
if (FRAME(2)-FRAME(1))==360.; 
  if size(xax, 2) == 1;
    XAX2 = [xax; xax(1)+360.]; 
  else
    XAX2 = [xax xax(1)+360.];
  end
  YAX2 = yax(yk);
  var1 = [var1(yk,:) var1(yk,1)];
  var2 = [var2(yk,:) var2(yk,1)];
else
  XAX2 = xax(xk);
  YAX2 = yax(yk);
  var1 = var1(yk, xk);
  var2 = var2(yk, xk);
end;
% contour var:
XAX2 = ones(length(YAX2), 1) * XAX2';
YAX2 = YAX2 * ones(1, size(XAX2, 2));

[h] = quiver_barb(XAX2, YAX2, var1, var2, 'barb');

%hold on
%plot(a(:,[1 3]), a(:,[2 4]), '-k');
%if clev > 0;
%  text(a(1,1), a(1,2), ' Max');%num2str(c(2)));
%  hx = xlabel(['Reference Arrow (Max) = ' ...
%               num2str(round(c(2)*100)/100) ' ' units]);
%elseif clev < 0;
%  hx = xlabel(['Reference Arrow = ' num2str(-1*clev) ' ' units]);
%end
%hold off;
axis([FRAME])
